===============
Grafanarmadillo
===============

.. image:: https://github.com/lilatomic/grafanarmadillo/workflows/Tests/badge.svg?branch=main
    :target: https://github.com/lilatomic/grafanarmadillo/actions?workflow=Tests
    :alt: Test Status

.. image:: https://codecov.io/gh/lilatomic/grafanarmadillo/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/lilatomic/grafanarmadillo
    :alt: Codecov

.. image:: https://api.codeclimate.com/v1/badges/d96cc9a1841a819cd4f5/maintainability
   :target: https://codeclimate.com/github/lilatomic/grafanarmadillo/maintainability
   :alt: Maintainability

.. image:: https://img.shields.io/readthedocs/grafanarmadillo/latest?label=Read%20the%20Docs
    :target: https://grafanarmadillo.readthedocs.io/en/latest/index.html
    :alt: Read the Docs

Summary
=======

Grafanarmadillo simplifies interacting with Grafana, with a focus on templating dashboards.

Library
-------

Grafanarmadillo is a library that navigates the Grafana API. It has helpers to find dashboards and alerts; make and fill templates; and provision those filled templates. See `usage <https://github.com/lilatomic/grafanarmadillo/tree/main/docs/rst/usage.rst>`_ for samples.

Tools
-----

Grafanarmadillo is a tool that helps turn dashboards and alerts into templates and to turn templates into dashboards and alerts. See `cli <https://github.com/lilatomic/grafanarmadillo/tree/main/docs/rst/cli.rst>`_

Acknowledgments
===============

This repository was built from the `skeleton <https://github.com/joaomcteixeira/python-project-skeleton>`_ developed by Joao M. C. Teixeira (`webpage <https://bit.ly/joaomcteixeira>`_, `github <https://github.com/joaomcteixeira>`_)

Version
=======

v0.9.0
